@@ -128,11 +128,11 @@ class LeapLoader:
                 setup_response = self.get_dataset_setup_response(handlers_test_payloads)
             except DatasetScriptException as e:
                 line_number, file_name, stacktrace = get_root_exception_file_and_line_number()
-                general_error = f"{repr(e.__cause__)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
+                general_error = f"Something went wrong. {repr(e.__cause__)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
                 is_valid = False
             except Exception as e:
                 line_number, file_name, stacktrace = get_root_exception_file_and_line_number()
-                general_error = f"{repr(e.__cause__)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
+                general_error = f"Something went wrong. {repr(e.__cause__)} in file {file_name}, line_number:  {line_number}\nStacktrace:\n{stacktrace}"
                 is_valid = False
 
         print_log = stdout_steam.getvalue()
